@@ -1,6 +1,6 @@
 package Dancer2::Core::Request;
 # ABSTRACT: Interface for accessing incoming requests
-$Dancer2::Core::Request::VERSION = '0.161000_01';
+$Dancer2::Core::Request::VERSION = '0.162000';
 use strict;
 use warnings;
 use parent 'Plack::Request';
@@ -326,7 +326,7 @@ sub params {
     }
 }
 
-sub captures { shift->params->{captures} }
+sub captures { shift->params->{captures} || {} }
 
 sub splat { @{ shift->params->{splat} || [] } }
 
@@ -574,7 +574,7 @@ Dancer2::Core::Request - Interface for accessing incoming requests
 
 =head1 VERSION
 
-version 0.161000_01
+version 0.162000
 
 =head1 SYNOPSIS
 
